QChatRoleResource enum

Inheritance
Available extensions

Values

manageServer → const QChatRoleResource

管理服务器:修改服务器,仅server有

manageChannel → const QChatRoleResource

管理频道,server和channel都有

manageRole → const QChatRoleResource

管理身份组的权限,server和channel都有

sendMsg → const QChatRoleResource

发送消息,server和channel都有

accountInfoSelf → const QChatRoleResource

修改自己在该server的服务器成员信息,仅server有

inviteServer → const QChatRoleResource

邀请他人进入server的,仅server有

kickServer → const QChatRoleResource

踢除他人的权限,仅server有

accountInfoOther → const QChatRoleResource

修改他人在该server的服务器成员信息,仅server有

recallMsg → const QChatRoleResource

撤回他人消息的权限,server和channel都有

deleteMsg → const QChatRoleResource

删除他人消息的权限,server和channel都有

remindOther → const QChatRoleResource

@ 他人的权限,server和channel都有

remindEveryone → const QChatRoleResource

@ everyone,server和channel都有

manageBlackWhiteList → const QChatRoleResource

管理黑白名单的权限,server和channel都有

banServerMember → const QChatRoleResource

封禁他人的权限,仅server有,允许成员永久封禁其他成员访问此服务器

rtcChannelConnect → const QChatRoleResource

RTC频道:连接的权限

rtcChannelDisconnectOther → const QChatRoleResource

RTC频道:断开他人连接的权限

rtcChannelOpenMicrophone → const QChatRoleResource

RTC频道:开启麦克风的权限

rtcChannelOpenCamera → const QChatRoleResource

RTC频道:开启摄像头的权限

rtcChannelOpenCloseOtherMicrophone → const QChatRoleResource

RTC频道:开启/关闭他人麦克风的权限

rtcChannelOpenCloseOtherCamera → const QChatRoleResource

RTC频道:开启/关闭他人摄像头的权限

rtcChannelOpenCloseEveryoneMicrophone → const QChatRoleResource

RTC频道:开启/关闭全员麦克风的权限

rtcChannelOpenCloseEveryoneCamera → const QChatRoleResource

RTC频道:开启/关闭全员摄像头的权限

rtcChannelOpenScreenShare → const QChatRoleResource

RTC频道:打开自己屏幕共享的权限

rtcChannelCloseOtherScreenShare → const QChatRoleResource

RTC频道:关闭他人屏幕共享的权限

serverApplyHandle → const QChatRoleResource

服务器申请处理权限

inviteApplyHistoryQuery → const QChatRoleResource

申请邀请历史查看权限,有这个权限才可以查询server级别的申请/邀请记录

mentionedRole → const QChatRoleResource

@身份组的权限,server和channel都有

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isAllPermission() bool

Available on QChatRoleResource, provided by the QChatRoleResourceExtension extension

是否是Server和Channel都拥有的权限
isOnlyChannelPermission() bool

Available on QChatRoleResource, provided by the QChatRoleResourceExtension extension

是否是仅Channel才拥有的权限
isOnlyServerPermission() bool

Available on QChatRoleResource, provided by the QChatRoleResourceExtension extension

是否是仅Server才拥有的权限
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
valueInfo() QChatRoleResourceValueInfo

Available on QChatRoleResource, provided by the QChatRoleResourceExtension extension

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<QChatRoleResource>
A constant List of the values in this enum, in order of their declaration.